==> DQScriptsDemo_0_2_1.zip: DQScriptsDemo_0_2_1/rgss-lib/dq/menu/Window_Skill.rb <==
#==============================================================================
#  Window_Skill
#------------------------------------------------------------------------------
# XLEBhE
# Copyright (C) 2005 fukuyama
#==============================================================================

module DQ

class Window_Skill < Window_Menu
  include Window_Tree_Module
  #--------------------------------------------------------------------------
  # 
  #--------------------------------------------------------------------------
  def initialize(parent)
    super(parent)
    # ʒu̐ݒ
    self.top  = top_window.top
    self.left = parent.right
  end
  #--------------------------------------------------------------------------
  # XV
  #--------------------------------------------------------------------------
  def refresh
    self.clear
    @actor = self.parent.actor
    if not @actor.nil?
      skills = Skill_Facade.actor_normal_skills @actor
      skills.each do |skill|
        add_menu(skill, :select_skill)
      end
    end
    super
  end
  #--------------------------------------------------------------------------
  # XL̎擾
  #--------------------------------------------------------------------------
  def skill
    return get_menu
  end
  #--------------------------------------------------------------------------
  # XLI
  #--------------------------------------------------------------------------
  def use_skill(owner_actor,target_actors)
    used = Skill_Facade.use_skill(skill,owner_actor,target_actors)
    # XLgꍇ
    if used
      # Sł̏ꍇ
      if $game_party.all_dead?
        # Q[I[o[ʂɐ؂ւ
        $scene = Scene_Gameover.new
        return
      end
      # RCxg ID L̏ꍇ
      if skill.common_event_id > 0
        # RCxgĂяo\
        $game_temp.common_event_id = skill.common_event_id
        # }bvʂɐ؂ւ
        $scene = Scene_Map.new
        return
      end
      msgs = []
      msgs.push "#{owner_actor.name}́@#{skill.name}@ƂȂI"

# TOOD XLɃbZ[Wݒ肷Kv

      e = Script_Event.new
      for msg in msgs
        e.message(msg)
      end
      e.brank
      $scene.interpreter.setup e.event_commands, 0
      @message_end = true
      return
    end
  end
  #--------------------------------------------------------------------------
  # XLI
  #--------------------------------------------------------------------------
  def select_skill
    actor = get_window(Window_Actor_Menu_Skill).actor
    skill = self.skill
    # gpłȂꍇ
    if skill == nil or not actor.skill_can_use?(skill.id)
      # SP Ȃꍇ͎gps
      if skill.sp_cost > actor.sp
        msg = "#{$data_system.words.sp}@ȂI"
        e = Script_Event.new
        e.message(msg)
        e.brank
        $scene.interpreter.setup e.event_commands, 0
        return
      end
      # 퓬s\̏ꍇ͎gps
      if dead?
        return
      end
      # ُԂ̏ꍇAXLȊO͎gps
      if skill.atk_f == 0 and actor.restriction == 1
        return
      end
      return
    end
    #  SE t
    $game_system.se_play($data_system.decision_se)
    # ʔ͈͂Ŝ̏ꍇ
    if skill.scope == 4
      use_skill(actor,$game_party.actors)
      return
    end
    if skill.scope == 6
      targets = []
      $game_party.actors.each do |actor|
        targets.push actor if actor.hp0?
      end
      use_skill(actor,targets)
      return
    end
    # ʔ͈͂P̂̏ꍇ
    if skill.scope == 3 or skill.scope == 5
      window = Window_Actor_Menu_Skill_Use.new(self)
      add_child window
      set_active_window(window.class)
      return
    end
  end
  #--------------------------------------------------------------------------
  # LZ
  #--------------------------------------------------------------------------
  def input_b
    cancel_se
    self.index = -1
    set_active_window(Window_Actor_Menu_Skill)
  end
  #--------------------------------------------------------------------------
  # ڂ̕`
  #--------------------------------------------------------------------------
  def draw_menu_item(index,color,rect,skill)
    self.contents.font.color = color
    self.contents.fill_rect(rect, Color.new(0, 0, 0, 0))
    self.contents.draw_text(rect, skill.name)
  end
  #---------------------------------------------------------------------------
  # Rec̍쐬
  def _contents_width
    return _menu_width * 1
  end
  #---------------------------------------------------------------------------
  # Rec̍쐬
  def _contents_height
    return _menu_height * 12
  end
  #---------------------------------------------------------------------------
  # j[̍쐬
  def _menu_height
    return super
  end
  #---------------------------------------------------------------------------
  # j[̍쐬
  def _menu_width
    return WINDOW_SKILL_WIDTH
  end
end

end

==> DQScriptsDemo_0_3.zip: DQScriptsDemo_0_3/rgss-lib/dq/menu/Window_Skill.rb <==
#==============================================================================
#  Window_Skill
#------------------------------------------------------------------------------
# XLEBhE
# Copyright (C) 2005 fukuyama
#==============================================================================

module DQ

class Window_Skill < Window_Menu
  include Window_Tree_Module
  include Menu_Log_Skill_Module
  #--------------------------------------------------------------------------
  # 
  #--------------------------------------------------------------------------
  def initialize(parent)
    super(parent)
    # ʒu̐ݒ
    self.top  = top_window.top
    self.left = parent.right
  end
  #--------------------------------------------------------------------------
  # XV
  #--------------------------------------------------------------------------
  def refresh
    self.clear
    @actor = self.parent.actor
    if not @actor.nil?
      skills = Skill_Facade.actor_normal_skills @actor
      skills.each do |skill|
        add_menu(skill, :select_skill)
      end
    end
    super
  end
  #--------------------------------------------------------------------------
  # XL̎擾
  #--------------------------------------------------------------------------
  def skill
    return get_menu
  end
  #--------------------------------------------------------------------------
  # XLI
  #--------------------------------------------------------------------------
  def select_skill
    actor = get_window(Window_Actor_Menu_Skill).actor
    skill = self.skill
    # gpłȂꍇ
    if skill == nil or not actor.skill_can_use?(skill.id)
      # SP Ȃꍇ͎gps
      if skill.sp_cost > actor.sp
        menu_log_use_skill_sp_cost_error(skill,actor)
        return
      end
      # 퓬s\̏ꍇ͎gps
      if actor.dead?
        menu_log_use_skill_actor_state_error(skill,actor)
        return
      end
      # ُԂ̏ꍇAXLȊO͎gps
      if skill.atk_f == 0 and actor.restriction == 1
        menu_log_use_skill_actor_state_error(skill,actor)
        return
      end
      return
    end
    #  SE t
    $game_system.se_play($data_system.decision_se)
    # ʔ͈͂P̂̏ꍇ
    if skill.scope == 3 or skill.scope == 5
      window = Window_Actor_Menu_Skill_Use.new(self)
      add_child window
      set_active_window(window.class)
      return
    end
    targets = []
    # ʔ͈͂Ŝ̏ꍇ
    if skill.scope == 4
      targets = $game_party.actors
    end
    # ʔ͈͂S(hp0)̏ꍇ
    if skill.scope == 6
      $game_party.actors.each do |actor|
        targets.push actor if actor.hp0?
      end
    end
    # XLgp
    used = Skill_Facade.use_skill(skill,actor,targets)
    # XLgꍇ
    if used
      menu_log_use_skill(skill,actor,targets)
      @message_end = true
    end
  end
  #--------------------------------------------------------------------------
  # LZ
  #--------------------------------------------------------------------------
  def input_b
    cancel_se
    self.index = -1
    set_active_window(Window_Actor_Menu_Skill)
  end
  #--------------------------------------------------------------------------
  # ڂ̕`
  #--------------------------------------------------------------------------
  def draw_menu_item(index,color,rect,skill)
    self.contents.font.color = color
    self.contents.fill_rect(rect, Color.new(0, 0, 0, 0))
    self.contents.draw_text(rect, skill.name)
  end
  #---------------------------------------------------------------------------
  # Rec̍쐬
  def _contents_width
    return _menu_width * 1
  end
  #---------------------------------------------------------------------------
  # Rec̍쐬
  def _contents_height
    return _menu_height * 12
  end
  #---------------------------------------------------------------------------
  # j[̍쐬
  def _menu_height
    return super
  end
  #---------------------------------------------------------------------------
  # j[̍쐬
  def _menu_width
    return WINDOW_SKILL_WIDTH
  end
end

end
